@@ -20,7 +20,7 @@ The Sys::Socket::Util class of L<SPVM> has methods for socket utilities.
 
 =head2 sockaddr_in
 
-  static method sockaddr_in : Sys::Socket::Sockaddr::In ($port : int, $in_addr : Sys::Socket::In_addr);
+C<static method sockaddr_in : L<Sys::Socket::Sockaddr::In|SPVM::Sys::Socket::Sockaddr::In> ($port : int, $in_addr : L<Sys::Socket::In_addr|SPVM::Sys::Socket::In_addr>);>
 
 Creates a L<Sys::Socket::Sockaddr::In|SPVM::Sys::Socket::Sockaddr::In> object given a port $port and a L<Sys::Socket::In_addr|SPVM::Sys::Socket::In_addr> object $in_addr, and returns it.
 
@@ -32,7 +32,7 @@ $in_addr must be defined. Otherwise an exception is thrown.
 
 =head2 sockaddr_in6
 
-  static method sockaddr_in6 : Sys::Socket::Sockaddr::In6 ($port : int, $in6_addr : Sys::Socket::In6_addr);
+C<static method sockaddr_in6 : L<Sys::Socket::Sockaddr::In6|SPVM::Sys::Socket::Sockaddr::In6> ($port : int, $in6_addr : L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr>);>
 
 Creates a L<Sys::Socket::Sockaddr::In6|SPVM::Sys::Socket::Sockaddr::In6> object given a port $port and a L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr> object $in_addr, and returns it.
 
@@ -44,7 +44,7 @@ $in6_addr must be defined. Otherwise an exception is thrown.
 
 =head2 sockaddr_un
 
-  static method sockaddr_un : Sys::Socket::Sockaddr::Un ($path : string);
+C<static method sockaddr_un : L<Sys::Socket::Sockaddr::Un|SPVM::Sys::Socket::Sockaddr::Un> ($path : string);>
 
 Creates a L<Sys::Socket::Sockaddr::Un|SPVM::Sys::Socket::Sockaddr::Un> object given a path $path, and returns it.
 
